@@ -1,7 +1,7 @@
 # ------------ Graphical User Interface ------------
 
 package Audio::Nama::Graphical;  ## gui routines
-use Modern::Perl; use Carp;
+use Modern::Perl '2020'; use Carp;
 our $VERSION = 1.071;
 use Audio::Nama::Globals qw($text $prompt);
 
